<div class="page-links">
  {{ if partial "private/has-headings.html" . -}}
    <h3>{{ i18n "on_this_page" }}</h3>
    {{ if eq site.Params.doks.scrollSpy true -}}
      {{ .TableOfContents | replaceRE "<nav id=\"TableOfContents\">" "<nav id=\"toc\">" | safeHTML -}}
    {{- else -}}
      {{ .TableOfContents -}}
    {{- end }}
  {{- end }}

  <!-- Feedback component below TOC -->
  <div class="feedback-links">
    <h3>Contribute</h3>
    <ul class="list-unstyled">
      <li><a href="https://github.com/covesa/s2dm/issues/new/choose">Create an issue</a></li>
      <li><a href="https://github.com/covesa/s2dm/discussions/new?category=ideas">Share an idea</a></li>
      <li><a href="https://github.com/covesa/s2dm/discussions/new?category=support">Ask a question</a></li>
    </ul>
  </div>
</div>
