{{ define "main" }}
<section class="section container-fluid mt-n3 pb-3">
  <div class="row justify-content-center">
    <div class="col-lg-12 text-center">
      <h1>{{ .Title }}</h1>
    </div>
    <div class="col-lg-9 col-xl-8 text-center">
      <p class="lead">{{ .Params.lead | safeHTML }}</p>
      <a class="btn btn-primary btn-cta rounded-pill btn-lg my-3" href="/docs/{{ if site.Params.doks.docsVersioning }}{{ site.Params.doks.docsVersion }}/{{ end }}guides/example-guide/" role="button">{{ i18n "get_started" }}</a>
      {{ .Content }}
    </div>
  </div>
</section>
{{ end }}

{{ define "sidebar-prefooter" }}
  {{ if site.Params.doks.backgroundDots -}}
  <div class="d-flex justify-content-start">
    <div class="bg-dots"></div>
  </div>
  {{ end -}}
  {{ if eq $.Site.Language.LanguageName "English" }}
  <section class="section section-md section-features">
    <div class="container">
      <div class="row justify-content-center text-center">
        <div class="col-lg-5">
          <h2 class="h4">Update content</h2>
          <p>Edit <code>content/_index.md</code> to see this page change.</p>
        </div>
        <div class="col-lg-5">
          <h2 class="h4">Add new content</h2>
          <p>Add Markdown files to <code>content</code> to create new pages.</p>
        </div>
        <div class="col-lg-5">
          <h2 class="h4">Configure your site</h2>
          <p>Edit your config in <code>config/_default/params.toml</code>.</p>
        </div>
        <div class="col-lg-5">
          <h2 class="h4">Read the docs</h2>
          <p>Learn more in the <a href="https://getdoks.org/">Docs</a>.</p>
        </div>
      </div>
    </div>
  </section>
  {{ end }}
{{ end }}

{{ define "sidebar-footer" }}
{{ if site.Params.doks.sectionFooter -}}
<section class="section section-md container-fluid bg-light">
  <div class="row justify-content-center text-center">
    <div class="col-lg-7">
      <h2 class="mt-2">Start building with Doks today</h2>
      <a class="btn btn-primary rounded-pill px-4 my-2" href="/docs/{{ if site.Params.doks.docsVersioning }}{{ site.Params.doks.docsVersion }}/{{ end }}prologue/introduction/" role="button">{{ i18n "get-started" }}</a>
    </div>
  </div>
</section>
{{ end -}}
{{ end }}
