"""
Describes signals related to the seat bottom of the seat.
"""
type Seating
  @metadata(
    comment: "Seating is here considered as the part of the seat that supports the thighs. Additional cushions (if any) for support of lower legs is not covered by this branch."
  ) {
  """
  Is switch to decrease seating length engaged.
  """
  isBackwardSwitchEngaged: Boolean
    @metadata(
      comment: "Affects the property (SingleSeat.Seating.Length)"
      vssType: "actuator"
    )

  """Is switch to increase seating length engaged."""
  isForwardSwitchEngaged: Boolean @metadata(vssType: "actuator")

  """
  Length adjustment of seating. 0 = Adjustable part of seating in rearmost position (Shortest length of seating).
  """
  length(unit: LengthUnit = MILLIM): UInt16 @metadata(vssType: "actuator")
}
