# Generated from QUDT units catalog version v3.1.6
enum VolumeFlowRateUnit @reference(uri: "http://qudt.org/vocab/quantitykind/VolumeFlowRate") {
  """Barrel (UK Petroleum) per Day"""
  BBL_UK_PET_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")

  """Barrel (UK Petroleum) per Hour"""
  BBL_UK_PET_PER_HR @reference(uri: "http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")

  """Barrel (UK Petroleum) per Minute"""
  BBL_UK_PET_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")

  """Barrel (UK Petroleum) per Second"""
  BBL_UK_PET_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")

  """Barrel (US) per Day | UCUM: [bbl_us].d-1"""
  BBL_US_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/BBL_US-PER-DAY")

  """Barrel (US) per Minute | UCUM: [bbl_us].min-1"""
  BBL_US_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/BBL_US-PER-MIN")

  """Barrel (us Petroleum) per Hour | UCUM: [bbl_us].h-1"""
  BBL_US_PET_PER_HR @reference(uri: "http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")

  """Barrel (us Petroleum) per Second | UCUM: [bbl_us].s-1"""
  BBL_US_PET_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")

  """Bushel (UK) per Day | UCUM: [bu_br].d-1"""
  BU_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/BU_UK-PER-DAY")

  """Bushel (UK) per Hour | UCUM: [bu_br].h-1"""
  BU_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/BU_UK-PER-HR")

  """Bushel (UK) per Minute | UCUM: [bu_br].min-1"""
  BU_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/BU_UK-PER-MIN")

  """Bushel (UK) per Second | UCUM: [bu_br].s-1"""
  BU_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BU_UK-PER-SEC")

  """Bushel (US Dry) per Day | UCUM: [bu_us].d-1"""
  BU_US_DRY_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")

  """Bushel (US Dry) per Hour | UCUM: [bu_us].h-1"""
  BU_US_DRY_PER_HR @reference(uri: "http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")

  """Bushel (US Dry) per Minute | UCUM: [bu_us].min-1"""
  BU_US_DRY_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")

  """Bushel (US Dry) per Second | UCUM: [bu_us].s-1"""
  BU_US_DRY_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")

  """Cubic Centimeter per Day | UCUM: cm3.d-1"""
  CENTIM3_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/CentiM3-PER-DAY")

  """Cubic Centimeter per Hour | UCUM: cm3.h-1"""
  CENTIM3_PER_HR @reference(uri: "http://qudt.org/vocab/unit/CentiM3-PER-HR")

  """Cubic Centimeter per Minute | UCUM: cm3.min-1"""
  CENTIM3_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/CentiM3-PER-MIN")

  """Cubic Centimeter per Second | UCUM: cm3.s-1"""
  CENTIM3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/CentiM3-PER-SEC")

  """Cubic Decimeter per Day | UCUM: dm3.d-1"""
  DECIM3_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/DeciM3-PER-DAY")

  """Cubic Decimeter per Hour | UCUM: dm3.h-1"""
  DECIM3_PER_HR @reference(uri: "http://qudt.org/vocab/unit/DeciM3-PER-HR")

  """Cubic Decimeter per Minute | UCUM: dm3.min-1"""
  DECIM3_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/DeciM3-PER-MIN")

  """Cubic Decimeter per Second | UCUM: dm3.s-1"""
  DECIM3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/DeciM3-PER-SEC")

  """Cubic Foot per Day | UCUM: [ft_i]3.d-1"""
  FT3_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/FT3-PER-DAY")

  """Cubic Foot per Hour | UCUM: [ft_i]3.h-1"""
  FT3_PER_HR @reference(uri: "http://qudt.org/vocab/unit/FT3-PER-HR")

  """Cubic Foot per Minute | UCUM: [ft_i]3.min-1"""
  FT3_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/FT3-PER-MIN")

  """Cubic Foot per Second | UCUM: [ft_i]3.s-1"""
  FT3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/FT3-PER-SEC")

  """Gallon (UK) per Day | UCUM: [gal_br].d-1"""
  GAL_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/GAL_UK-PER-DAY")

  """Gallon (UK) per Hour | UCUM: [gal_br].h-1"""
  GAL_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/GAL_UK-PER-HR")

  """Gallon (UK) per Minute | UCUM: [gal_br].min-1"""
  GAL_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/GAL_UK-PER-MIN")

  """Gallon (UK) per Second | UCUM: [gal_br].s-1"""
  GAL_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/GAL_UK-PER-SEC")

  """Us Gallon per Day | UCUM: [gal_us].d-1"""
  GAL_US_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/GAL_US-PER-DAY")

  """Us Gallon per Hour | UCUM: [gal_us].h-1"""
  GAL_US_PER_HR @reference(uri: "http://qudt.org/vocab/unit/GAL_US-PER-HR")

  """Us Gallon per Minute | UCUM: [gal_us].min-1"""
  GAL_US_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/GAL_US-PER-MIN")

  """Us Gallon per Second | UCUM: [gal_us].s-1"""
  GAL_US_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/GAL_US-PER-SEC")

  """Gill (UK) per Day | UCUM: [gil_br].d-1"""
  GI_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/GI_UK-PER-DAY")

  """Gill (UK) per Hour | UCUM: [gil_br].h-1"""
  GI_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/GI_UK-PER-HR")

  """Gill (UK) per Minute | UCUM: [gil_br].min-1"""
  GI_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/GI_UK-PER-MIN")

  """Gill (UK) per Second | UCUM: [gil_br].s-1"""
  GI_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/GI_UK-PER-SEC")

  """Gill (US) per Day | UCUM: [gil_us].d-1"""
  GI_US_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/GI_US-PER-DAY")

  """Gill (US) per Hour | UCUM: [gil_us].h-1"""
  GI_US_PER_HR @reference(uri: "http://qudt.org/vocab/unit/GI_US-PER-HR")

  """Gill (US) per Minute | UCUM: [gil_us].min-1"""
  GI_US_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/GI_US-PER-MIN")

  """Gill (US) per Second | UCUM: [gil_us].s-1"""
  GI_US_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/GI_US-PER-SEC")

  """Cubic Inch per Hour | UCUM: [in_i]3.h-1"""
  IN3_PER_HR @reference(uri: "http://qudt.org/vocab/unit/IN3-PER-HR")

  """Cubic Inch per Minute | UCUM: [in_i]3.min-1"""
  IN3_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/IN3-PER-MIN")

  """Cubic Inch per Second | UCUM: [in_i]3.s-1"""
  IN3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/IN3-PER-SEC")

  """Kiloliter per Hour | UCUM: kL.h-1"""
  KILOL_PER_HR @reference(uri: "http://qudt.org/vocab/unit/KiloL-PER-HR")

  """Liter per Day | UCUM: L.d-1"""
  L_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/L-PER-DAY")

  """Liter per Hour | UCUM: L.h-1"""
  L_PER_HR @reference(uri: "http://qudt.org/vocab/unit/L-PER-HR")

  """Liter per Minute | UCUM: L.min-1"""
  L_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/L-PER-MIN")

  """Liter per Second | UCUM: L.s-1"""
  L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/L-PER-SEC")

  """Cubic Meter per Day | UCUM: m3.d-1"""
  M3_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/M3-PER-DAY")

  """Cubic Meter per Hour | UCUM: m3.h-1"""
  M3_PER_HR @reference(uri: "http://qudt.org/vocab/unit/M3-PER-HR")

  """Cubic Meter per Minute | UCUM: m3.min-1"""
  M3_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/M3-PER-MIN")

  """Cubic Meter per Second | UCUM: m3.s-1"""
  M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/M3-PER-SEC")

  """Cubic Meter per Year | UCUM: m3.a-1"""
  M3_PER_YR @reference(uri: "http://qudt.org/vocab/unit/M3-PER-YR")

  """Milliliter per Day | UCUM: mL.d-1"""
  MILLIL_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/MilliL-PER-DAY")

  """Milliliter per Hour | UCUM: mL.h-1"""
  MILLIL_PER_HR @reference(uri: "http://qudt.org/vocab/unit/MilliL-PER-HR")

  """Milliliter per Minute | UCUM: mL.min-1"""
  MILLIL_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/MilliL-PER-MIN")

  """Milliliter per Second | UCUM: mL.s-1"""
  MILLIL_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MilliL-PER-SEC")

  """Fluid Ounce (UK) per Day | UCUM: [foz_br].d-1"""
  OZ_VOL_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")

  """Fluid Ounce (UK) per Hour | UCUM: [foz_br].h-1"""
  OZ_VOL_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")

  """Fluid Ounce (UK) per Minute | UCUM: [foz_br].min-1"""
  OZ_VOL_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")

  """Fluid Ounce (UK) per Second | UCUM: [foz_br].s-1"""
  OZ_VOL_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")

  """Us Liquid Ounce per Day | UCUM: [foz_us].d-1"""
  OZ_VOL_US_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")

  """Us Liquid Ounce per Hour | UCUM: [foz_us].h-1"""
  OZ_VOL_US_PER_HR @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")

  """Us Liquid Ounce per Minute | UCUM: [foz_us].min-1"""
  OZ_VOL_US_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")

  """Us Liquid Ounce per Second | UCUM: [foz_us].s-1"""
  OZ_VOL_US_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")

  """Pint (UK) per Day | UCUM: [pt_br].d-1"""
  PINT_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/PINT_UK-PER-DAY")

  """Pint (UK) per Hour | UCUM: [pt_br].h-1"""
  PINT_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/PINT_UK-PER-HR")

  """Pint (UK) per Minute | UCUM: [pt_br].min-1"""
  PINT_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/PINT_UK-PER-MIN")

  """Pint (UK) per Second | UCUM: [pt_br].s-1"""
  PINT_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PINT_UK-PER-SEC")

  """Us Liquid Pint per Day | UCUM: [pt_us].d-1"""
  PINT_US_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/PINT_US-PER-DAY")

  """Us Liquid Pint per Hour | UCUM: [pt_us].h-1"""
  PINT_US_PER_HR @reference(uri: "http://qudt.org/vocab/unit/PINT_US-PER-HR")

  """Us Liquid Pint per Minute | UCUM: [pt_us].min-1"""
  PINT_US_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/PINT_US-PER-MIN")

  """Us Liquid Pint per Second | UCUM: [pt_us].s-1"""
  PINT_US_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PINT_US-PER-SEC")

  """Peck (UK) per Day | UCUM: [pk_br].d-1"""
  PK_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/PK_UK-PER-DAY")

  """Peck (UK) per Hour | UCUM: [pk_br].h-1"""
  PK_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/PK_UK-PER-HR")

  """Peck (UK) per Minute | UCUM: [pk_br].min-1"""
  PK_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/PK_UK-PER-MIN")

  """Peck (UK) per Second | UCUM: [pk_br].s-1"""
  PK_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PK_UK-PER-SEC")

  """Us Peck per Day | UCUM: [pk_us].d-1"""
  PK_US_DRY_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")

  """Us Peck per Hour | UCUM: [pk_us].h-1"""
  PK_US_DRY_PER_HR @reference(uri: "http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")

  """Us Peck per Minute | UCUM: [pk_us].min-1"""
  PK_US_DRY_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")

  """Us Peck per Second | UCUM: [pk_us].s-1"""
  PK_US_DRY_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")

  """Quart (UK) per Day | UCUM: [qt_br].d-1"""
  QT_UK_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/QT_UK-PER-DAY")

  """Quart (UK) per Hour | UCUM: [qt_br].h-1"""
  QT_UK_PER_HR @reference(uri: "http://qudt.org/vocab/unit/QT_UK-PER-HR")

  """Quart (UK) per Minute | UCUM: [qt_br].min-1"""
  QT_UK_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/QT_UK-PER-MIN")

  """Quart (UK) per Second | UCUM: [qt_br].s-1"""
  QT_UK_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/QT_UK-PER-SEC")

  """Us Liquid Quart per Day | UCUM: [qt_us].d-1"""
  QT_US_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/QT_US-PER-DAY")

  """Us Liquid Quart per Hour | UCUM: [qt_us].h-1"""
  QT_US_PER_HR @reference(uri: "http://qudt.org/vocab/unit/QT_US-PER-HR")

  """Us Liquid Quart per Minute | UCUM: [qt_us].min-1"""
  QT_US_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/QT_US-PER-MIN")

  """Us Liquid Quart per Second | UCUM: [qt_us].s-1"""
  QT_US_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/QT_US-PER-SEC")

  """Cubic Yard per Day | UCUM: [yd_i]3.d-1"""
  YD3_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/YD3-PER-DAY")

  """Cubic Yard per Hour | UCUM: [yd_i]3.h-1"""
  YD3_PER_HR @reference(uri: "http://qudt.org/vocab/unit/YD3-PER-HR")

  """Cubic Yard per Minute | UCUM: [yd_i]3.min-1"""
  YD3_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/YD3-PER-MIN")

  """Cubic Yard per Second | UCUM: [yd_i]3.s-1"""
  YD3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/YD3-PER-SEC")
}
