# Generated from QUDT units catalog version 3.1.5
enum AngleUnit @reference(uri: "http://qudt.org/vocab/quantitykind/Angle") {
  """Arcminute | UCUM: '"""
  ARCMIN @reference(uri: "http://qudt.org/vocab/unit/ARCMIN")

  """Arcsecond | UCUM: ''"""
  ARCSEC @reference(uri: "http://qudt.org/vocab/unit/ARCSEC")

  """Degree | UCUM: deg"""
  DEG @reference(uri: "http://qudt.org/vocab/unit/DEG")

  """Gon | UCUM: gon"""
  GON @reference(uri: "http://qudt.org/vocab/unit/GON")

  """Grad"""
  GRAD @reference(uri: "http://qudt.org/vocab/unit/GRAD")

  """Microradian | UCUM: urad"""
  MICRORAD @reference(uri: "http://qudt.org/vocab/unit/MicroRAD")

  """Mil Angle (nato)"""
  MIL @reference(uri: "http://qudt.org/vocab/unit/MIL")

  """Milliarcsecond | UCUM: m''"""
  MILLIARCSEC @reference(uri: "http://qudt.org/vocab/unit/MilliARCSEC")

  """Milliradian | UCUM: mrad"""
  MILLIRAD @reference(uri: "http://qudt.org/vocab/unit/MilliRAD")

  """Minute Angle | UCUM: '"""
  MIN_ANGLE @reference(uri: "http://qudt.org/vocab/unit/MIN_Angle")

  """Radian | UCUM: rad"""
  RAD @reference(uri: "http://qudt.org/vocab/unit/RAD")

  """Revolution"""
  REV @reference(uri: "http://qudt.org/vocab/unit/REV")
}
