"""Headrest settings."""
type Headrest {
  """
  Headrest angle, relative to backrest, 0 degrees if parallel to backrest, Positive degrees = tilted forward.
  """
  angle(unit: AngleUnit = DEG): Float @metadata(vssType: "actuator")

  """
  Position of headrest relative to movable range of the head rest. 0 = Bottommost position supported.
  """
  height(unit: LengthUnit = MILLIM): UInt8 @metadata(vssType: "actuator")

  """
  Head rest backward switch engaged.
  """
  isBackwardSwitchEngaged: Boolean @metadata(comment:"Affects the property (SingleSeat.Headrest.Angle)", vssType:"actuator")

  """
  Head rest down switch engaged.
  """
  isDownSwitchEngaged: Boolean @metadata(comment:"Affects the property (SingleSeat.Headrest.Height)", vssType:"actuator")

  """
  Head rest forward switch engaged.
  """
  isForwardSwitchEngaged: Boolean @metadata(comment:"Affects the property (SingleSeat.Headrest.Angle)", vssType:"actuator")

  """
  Head rest up switch engaged.
  """
  isUpSwitchEngaged: Boolean @metadata(comment:"Affects the property (SingleSeat.Headrest.Height)", vssType:"actuator")
}
