export function Separator() {
	return (
		<div className="flex justify-center py-4">
			<div
				className="w-[85%] h-1 rounded-full"
				style={{ boxShadow: "inset 0 1px 3px rgba(0,0,0,0.4)" }}
			/>
		</div>
	);
}
