# Generated from QUDT units catalog version v3.1.6
enum PowerUnit @reference(uri: "http://qudt.org/vocab/quantitykind/Power") {
  """Bar Liter per Second | UCUM: bar.L.s-1"""
  BAR_L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BAR-L-PER-SEC")

  """Bar Cubic Meter per Second | UCUM: bar.m3.s-1"""
  BAR_M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BAR-M3-PER-SEC")

  """British Thermal Unit (international Definition) per Hour | UCUM: [Btu_IT].h-1"""
  BTU_IT_PER_HR @reference(uri: "http://qudt.org/vocab/unit/BTU_IT-PER-HR")

  """British Thermal Unit (international Definition) per Second | UCUM: [Btu_IT].s-1"""
  BTU_IT_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/BTU_IT-PER-SEC")

  """Erg per Second | UCUM: erg.s-1"""
  ERG_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/ERG-PER-SEC")

  """Exajoule per Second | UCUM: EJ.s-1"""
  EXAJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/ExaJ-PER-SEC")

  """Exawatt | UCUM: EW"""
  EXAW @reference(uri: "http://qudt.org/vocab/unit/ExaW")

  """Foot Pound Force per Hour | UCUM: [ft_i].[lbf_av].h-1"""
  FT_LB_F_PER_HR @reference(uri: "http://qudt.org/vocab/unit/FT-LB_F-PER-HR")

  """Foot Pound Force per Minute | UCUM: [ft_i].[lbf_av].min-1"""
  FT_LB_F_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")

  """Foot Pound Force per Second | UCUM: [ft_i].[lbf_av].s-1"""
  FT_LB_F_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")

  """Gigajoule per Hour | UCUM: GJ.h-1"""
  GIGAJ_PER_HR @reference(uri: "http://qudt.org/vocab/unit/GigaJ-PER-HR")

  """Gigajoule per Second | UCUM: GJ.s-1"""
  GIGAJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/GigaJ-PER-SEC")

  """Gigawatt | UCUM: GW"""
  GIGAW @reference(uri: "http://qudt.org/vocab/unit/GigaW")

  """Hectopascal Liter per Second | UCUM: hPa.L.s-1"""
  HECTOPA_L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")

  """Hectopascal Cubic Meter per Second | UCUM: hPa.m3.s-1"""
  HECTOPA_M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")

  """Horsepower | UCUM: [HP]"""
  HP @reference(uri: "http://qudt.org/vocab/unit/HP")

  """Boiler Horsepower"""
  HP_BOILER @reference(uri: "http://qudt.org/vocab/unit/HP_Boiler")

  """Horsepower (brake)"""
  HP_BRAKE @reference(uri: "http://qudt.org/vocab/unit/HP_Brake")

  """Horsepower (electric)"""
  HP_ELECTRIC @reference(uri: "http://qudt.org/vocab/unit/HP_Electric")

  """Horsepower (water)"""
  HP_H2O @reference(uri: "http://qudt.org/vocab/unit/HP_H2O")

  """Horsepower (metric)"""
  HP_METRIC @reference(uri: "http://qudt.org/vocab/unit/HP_Metric")

  """Joule per Day | UCUM: J.d-1"""
  J_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/J-PER-DAY")

  """Joule per Hour | UCUM: J.h-1"""
  J_PER_HR @reference(uri: "http://qudt.org/vocab/unit/J-PER-HR")

  """Joule per Minute | UCUM: J.min-1"""
  J_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/J-PER-MIN")

  """Joule per Second | UCUM: J.s-1"""
  J_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/J-PER-SEC")

  """Kilo British Thermal Unit (international Definition) per Hour | UCUM: k[Btu_IT].h-1"""
  KILOBTU_IT_PER_HR @reference(uri: "http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")

  """Kilocalorie per Minute | UCUM: kcal.min-1"""
  KILOCAL_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/KiloCAL-PER-MIN")

  """Kilocalorie per Second | UCUM: kcal.s-1"""
  KILOCAL_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/KiloCAL-PER-SEC")

  """Kilo Gram Force Meter per Second | UCUM: kgf.m.s-1"""
  KILOGM_F_M_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")

  """Kilojoule per Day | UCUM: kJ.d-1"""
  KILOJ_PER_DAY @reference(uri: "http://qudt.org/vocab/unit/KiloJ-PER-DAY")

  """Kilojoule per Hour | UCUM: kJ.h-1"""
  KILOJ_PER_HR @reference(uri: "http://qudt.org/vocab/unit/KiloJ-PER-HR")

  """Kilojoule per Minute | UCUM: kJ.min-1"""
  KILOJ_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/KiloJ-PER-MIN")

  """Kilojoule per Second | UCUM: kJ.s-1"""
  KILOJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/KiloJ-PER-SEC")

  """Kilowatt | UCUM: kW"""
  KILOW @reference(uri: "http://qudt.org/vocab/unit/KiloW")

  """Mega British Thermal Unit (international Definition) per Hour | UCUM: M[Btu_IT].h-1"""
  MEGABTU_IT_PER_HR @reference(uri: "http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")

  """Megajoule per Hour | UCUM: MJ.h-1"""
  MEGAJ_PER_HR @reference(uri: "http://qudt.org/vocab/unit/MegaJ-PER-HR")

  """Megajoule per Second | UCUM: MJ.s-1"""
  MEGAJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MegaJ-PER-SEC")

  """Megapascal Liter per Second | UCUM: MPa.L.s-1"""
  MEGAPA_L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")

  """Megapascal Cubic Meter per Second | UCUM: MPa.m3.s-1"""
  MEGAPA_M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")

  """Megawatt | UCUM: MW"""
  MEGAW @reference(uri: "http://qudt.org/vocab/unit/MegaW")

  """Micro Joule per Second | UCUM: uJ.s-1"""
  MICROJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MicroJ-PER-SEC")

  """Microwatt | UCUM: uW"""
  MICROW @reference(uri: "http://qudt.org/vocab/unit/MicroW")

  """Millibar Liter per Second | UCUM: mbar.L.s-1"""
  MILLIBAR_L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")

  """Millibar Cubic Meter per Second | UCUM: mbar.m3.s-1"""
  MILLIBAR_M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")

  """Millijoule per Second | UCUM: mJ.s-1"""
  MILLIJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/MilliJ-PER-SEC")

  """Milliwatt | UCUM: mW"""
  MILLIW @reference(uri: "http://qudt.org/vocab/unit/MilliW")

  """Nanojoule per Second | UCUM: nJ.s-1"""
  NANOJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/NanoJ-PER-SEC")

  """Nanowatt | UCUM: nW"""
  NANOW @reference(uri: "http://qudt.org/vocab/unit/NanoW")

  """Pascal Liter per Second | UCUM: Pa.L.s-1"""
  PA_L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PA-L-PER-SEC")

  """Pascal Cubic Meter per Second | UCUM: Pa.m3.s-1"""
  PA_M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PA-M3-PER-SEC")

  """Petajoule per Second | UCUM: PJ.s-1"""
  PETAJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PetaJ-PER-SEC")

  """Petawatt | UCUM: PW"""
  PETAW @reference(uri: "http://qudt.org/vocab/unit/PetaW")

  """Pferdestaerke"""
  PFERDESTAERKE @reference(uri: "http://qudt.org/vocab/unit/PFERDESTAERKE")

  """Picojoule per Second | UCUM: pJ.s-1"""
  PICOJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PicoJ-PER-SEC")

  """Picowatt | UCUM: pW"""
  PICOW @reference(uri: "http://qudt.org/vocab/unit/PicoW")

  """Planck Power"""
  PLANCKPOWER @reference(uri: "http://qudt.org/vocab/unit/PlanckPower")

  """Psi Cubic Inch per Second | UCUM: [psi].[in_i]3.s-1"""
  PSI_IN3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")

  """Psi Liter per Second | UCUM: [psi].L.s-1"""
  PSI_L_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PSI-L-PER-SEC")

  """Psi Cubic Meter per Second | UCUM: [psi].m3.s-1"""
  PSI_M3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PSI-M3-PER-SEC")

  """Psi Cubic Yard per Second | UCUM: [psi].[yd_i]3.s-1"""
  PSI_YD3_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")

  """Terajoule per Second | UCUM: TJ.s-1"""
  TERAJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/TeraJ-PER-SEC")

  """Terawatt | UCUM: TW"""
  TERAW @reference(uri: "http://qudt.org/vocab/unit/TeraW")

  """Terawatt Hour per Year | UCUM: TW.h.a-1"""
  TERAW_HR_PER_YR @reference(uri: "http://qudt.org/vocab/unit/TeraW-HR-PER-YR")

  """Therm Us per Hour | UCUM: 100000.[Btu_59].h-1"""
  THM_US_PER_HR @reference(uri: "http://qudt.org/vocab/unit/THM_US-PER-HR")

  """Ton of Refrigeration"""
  TON_FG @reference(uri: "http://qudt.org/vocab/unit/TON_FG")

  """Watt | UCUM: W"""
  W @reference(uri: "http://qudt.org/vocab/unit/W")
}
