"""Axle signals for vehicles (towing or towed) with 1 to 15 axles"""
type VehicleTrailerAxle {
    """The static vertical load of a trailer axle in kilograms."""
    axleLoad: UInt16

    """
    The lateral distance between the wheel mounting faces, measured along the spindle axis.
    """
    axleWidth(unit: LengthUnit = MILLIM): UInt16 @metadata(comment: "Corresponds to SAE J1100-2009 W113.")

    """
    Axle position from 1 to 15, 1 being in the front closest to the truck, according to ISO 11992-2.
    """
    position: AxlePositionEnum  # <-- This is the same as the one used in instantiation.

    """
    Single track two-axle model steering angle. Angle according to ISO 8855. Positive = degrees to the left. Negative = degrees to the right.
    """
    steeringAngle(unit: AngleUnit = DEG): Float
    @metadata(comment: "@comment: Single track two-axle model steering angle refers to the angle that a centrally mounted wheel would have.")

    """
    Aspect ratio between tire section height and tire section width, as per ETRTO / TRA standard.
    """
    tireAspectRatio(unit: DimensionlessRatioUnit = PERCENT): UInt8

    """Outer diameter of tires, in inches, as per ETRTO / TRA standard."""
    tireDiameter(unit: LengthUnit = IN): Float

    """Nominal section width of tires, in mm, as per ETRTO / TRA standard."""
    tireWidth(unit: LengthUnit = MILLIM): UInt16

    """
    The lateral distance between the centers of the wheels, measured along the spindle, or axle axis. If there are dual rear wheels, measure from the midway points between the inner and outer tires.
    """
    trackWidth(unit: LengthUnit = MILLIM): UInt16 @metadata(comment: "Corresponds to SAE J1100-2009 W102.")

    """
    The lateral distance between the centerlines of the base tires at ground, including camber angle. If there are dual rear wheels, measure from the midway points between the inner and outer tires.
    """
    treadWidth(unit: LengthUnit = MILLIM): UInt16 @metadata(comment: "Corresponds to SAE J1100-2009 W101.")

    """
    Diameter of wheels (rims without tires), in inches, as per ETRTO / TRA standard.
    """
    wheelDiameter(unit: LengthUnit = IN): Float

    """
    Width of wheels (rims without tires), in inches, as per ETRTO / TRA standard.
    """
    wheelWidth(unit: LengthUnit = IN): Float

    """List of wheels on the axle."""
    wheels: [VehicleTrailerWheel]

    """Number of wheels on the axle"""
    wheelCount: UInt8 # <-- This could be directly counted from the "wheels" list.
}
