# Generated from QUDT units catalog version v3.1.6
enum ElectricPowerUnit @reference(uri: "http://qudt.org/vocab/quantitykind/ElectricPower") {
  """Exawatt | UCUM: EW"""
  EXAW @reference(uri: "http://qudt.org/vocab/unit/ExaW")

  """Gigawatt | UCUM: GW"""
  GIGAW @reference(uri: "http://qudt.org/vocab/unit/GigaW")

  """Kilowatt | UCUM: kW"""
  KILOW @reference(uri: "http://qudt.org/vocab/unit/KiloW")

  """Megawatt | UCUM: MW"""
  MEGAW @reference(uri: "http://qudt.org/vocab/unit/MegaW")

  """Microwatt | UCUM: uW"""
  MICROW @reference(uri: "http://qudt.org/vocab/unit/MicroW")

  """Milliwatt | UCUM: mW"""
  MILLIW @reference(uri: "http://qudt.org/vocab/unit/MilliW")

  """Nanowatt | UCUM: nW"""
  NANOW @reference(uri: "http://qudt.org/vocab/unit/NanoW")

  """Petawatt | UCUM: PW"""
  PETAW @reference(uri: "http://qudt.org/vocab/unit/PetaW")

  """Picowatt | UCUM: pW"""
  PICOW @reference(uri: "http://qudt.org/vocab/unit/PicoW")

  """Terajoule per Second | UCUM: TJ.s-1"""
  TERAJ_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/TeraJ-PER-SEC")

  """Terawatt | UCUM: TW"""
  TERAW @reference(uri: "http://qudt.org/vocab/unit/TeraW")

  """Watt | UCUM: W"""
  W @reference(uri: "http://qudt.org/vocab/unit/W")
}
