# Generated from QUDT units catalog version v3.1.6
enum HeartRateUnit @reference(uri: "http://qudt.org/vocab/quantitykind/HeartRate") {
  """Heart Beats per Minute | UCUM: min-1{H.B.}"""
  BEAT_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/BEAT-PER-MIN")
}
