"""An object representing a vehicle."""
type Vehicle {
    vin: ID!

    """Maximum vertical weight on the tow ball of a trailer."""
    maxTowBallWeight(unit: MassUnit = KILOGM): UInt16

    """Maximum weight of trailer."""
    maxTowWeight(unit: MassUnit = KILOGM): UInt16

    """List of trailers attached to the vehicle."""
    trailers: [VehicleTrailer]

    """Number of trailers connected to the vehicle"""
    trailerCount: UInt8  # <-- This could be directly counted from the "trailers" list.
}
