type Query {
  """Get full Seat object for given position"""
  getSeat(instanceTag: InCabinArea2x2Input!): Seat

  """Get seat position (x-axis in mm)"""
  getSeatPosition(instanceTag: InCabinArea2x2Input!): UInt16

  """Get seat height (z-axis in mm)"""
  getSeatHeight(instanceTag: InCabinArea2x2Input!): UInt16

  """Get seat tilt angle in degrees"""
  getSeatTilt(instanceTag: InCabinArea2x2Input!): Float

  """Get massage level (0–100%)"""
  getSeatMassageLevel(instanceTag: InCabinArea2x2Input!): UInt8

  """Is the seat currently occupied"""
  isSeatOccupied(instanceTag: InCabinArea2x2Input!): Boolean
}
