# Generated from QUDT units catalog version 3.1.5
enum AngularVelocityUnit @reference(uri: "http://qudt.org/vocab/quantitykind/AngularVelocity") {
  """Degree per Hour | UCUM: deg.h-1"""
  DEG_PER_HR @reference(uri: "http://qudt.org/vocab/unit/DEG-PER-HR")

  """Degree per Minute | UCUM: deg.min-1"""
  DEG_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/DEG-PER-MIN")

  """Degree per Second | UCUM: deg.s-1"""
  DEG_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/DEG-PER-SEC")

  """Planck Angular Frequency"""
  PLANCKFREQUENCY_ANG @reference(uri: "http://qudt.org/vocab/unit/PlanckFrequency_Ang")

  """Radian per Hour | UCUM: rad.h-1"""
  RAD_PER_HR @reference(uri: "http://qudt.org/vocab/unit/RAD-PER-HR")

  """Radian per Minute | UCUM: rad.min-1"""
  RAD_PER_MIN @reference(uri: "http://qudt.org/vocab/unit/RAD-PER-MIN")

  """Radian per Second | UCUM: rad.s-1"""
  RAD_PER_SEC @reference(uri: "http://qudt.org/vocab/unit/RAD-PER-SEC")
}
